==> nextcloud-30.0.5.tgz: nextcloud/apps/updatenotification/l10n/ug.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "قانال يېڭىلاندى",
    "Web updater is disabled" : "تور يېڭىلاش ئىقتىدارى چەكلەنگەن",
    "App updated" : "ئەپ يېڭىلاندى",
    "See what's new" : "يېڭى نەرسىلەرنى كۆرۈڭ",
    "{app} updated to version {version}" : "{app} نەشرىگە يېڭىلاندى {version}",
    "Update notifications" : "ئۇقتۇرۇشنى يېڭىلاش",
    "The update server could not be reached since %d days to check for new updates." : "يېڭىلاش مۇلازىمىتىرى% d كۈندىن باشلاپ يېڭى يېڭىلانمىلارنى تەكشۈرۈشكە ئېرىشەلمىدى.",
    "Please check the Nextcloud and server log files for errors." : "Nextcloud ۋە مۇلازىمېتىر خاتىرى ھۆججىتىنىڭ خاتالىقلىرىنى تەكشۈرۈپ بېقىڭ.",
    "Update to {serverAndVersion} is available." : "{serverAndVersion} to غا يېڭىلاشقا بولىدۇ.",
    "Update for {app} to version %s is available." : "{app} نى% s نەشرىگە يېڭىلاشقا بولىدۇ.",
    "Update notification" : "ئۇقتۇرۇشنى يېڭىلاش",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Nextcloud نىڭ يېڭىلاش ئۇقتۇرۇشى ، ئەپ يېڭىلانمىلىرىنى كۆرسىتىدۇ ۋە يېڭىلاش ئۈچۈن SSO تەمىنلەيدۇ.",
    "What's new in {app} {version}" : "{app} {version} يېڭىلىق نېمە",
    "Give feedback" : "پىكىر بېرىڭ",
    "Get started" : "باشلاڭ",
    "No changelog available" : "ئۆزگەرتكىلى بولمايدۇ",
    "Update" : "يېڭىلا",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "سىز ئىجرا قىلىۋاتقان نەشرى ئەمدى ساقلاپ قېلىنمايدۇ. قوللايدىغان نەشرىگە بالدۇرراق يېڭىلاشقا كاپالەتلىك قىلىڭ.",
    "Apps missing compatible version" : "ماس كېلىدىغان نەشرى يوق",
    "View in store" : "دۇكاندا كۆرۈش",
    "Apps with compatible version" : "ماس نەشرى بار ئەپلەر",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "شۇنىڭغا دىققەت قىلىڭكى ، 100 دىن ئارتۇق ھېسابات بىلەن تور يېڭىلاش تەۋسىيە قىلىنمايدۇ! ئۇنىڭ ئورنىغا بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ!",
    "Open updater" : "يېڭىلاشنى ئېچىڭ",
    "Download now" : "ھازىر چۈشۈرۈڭ",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "تور يېڭىلاش ئىقتىدارى چەكلەنگەن. يېڭىلاش ئۈچۈن بۇيرۇق قۇرىنى يېڭىلاش ياكى قاچىلاش ئۇسۇلىڭىزغا ماس كېلىدىغان يېڭىلاش مېخانىزمىنى ئىشلىتىڭ.",
    "What's new?" : "نېمە يېڭىلىق؟",
    "View changelog" : "Changelog نى كۆرۈڭ",
    "The update check is not yet finished. Please refresh the page." : "يېڭىلاش تەكشۈرۈشى تېخى تاماملانمىدى. بەتنى يېڭىلاڭ.",
    "Your version is up to date." : "نەشرىڭىز يېڭىلاندى.",
    "A non-default update server is in use to be checked for updates:" : "يېڭىلانمىلارنى تەكشۈرۈش ئۈچۈن سۈكۈتتىكى يېڭىلاش مۇلازىمىتىرى ئىشلىتىلىۋاتىدۇ:",
    "Update channel" : "قانالنى يېڭىلاش",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "يېڭىلاش قانىلىنى ئۆزگەرتىش ئەپ باشقۇرۇش بېتىگىمۇ تەسىر كۆرسىتىدۇ. مەسىلەن: beta قانىلىغا ئۆتكەندىن كېيىن ، ئەپ باشقۇرۇش بېتىدە beta ئەپ يېڭىلانمىلىرى سىزگە تەمىنلىنىدۇ.",
    "Current update channel:" : "نۆۋەتتىكى يېڭىلاش قانىلى:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "سىز ھەمىشە يېڭى نەشرىگە يېڭىلىيالايسىز. ئەمما سىز تېخىمۇ مۇقىم نەشرىگە ھەرگىز چۈشۈرەلمەيسىز.",
    "Notify members of the following groups about available updates:" : "تۆۋەندىكى گۇرۇپپىلارنىڭ ئەزالىرىغا بار بولغان يېڭىلانمىلارنى ئۇقتۇرۇڭ:",
    "No groups" : "گۇرۇپپا يوق",
    "Only notifications for app updates are available." : "پەقەت ئەپ يېڭىلاش ھەققىدىكى ئۇقتۇرۇشلارلا بار.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "تاللانغان يېڭىلاش قانىلى مۇلازىمېتىرنىڭ ۋاقتى ئۆتكەن.",
    "The selected update channel does not support updates of the server." : "تاللانغان يېڭىلاش قانىلى مۇلازىمېتىرنىڭ يېڭىلىنىشىنى قوللىمايدۇ.",
    "A new version is available: <strong>{newVersionString}</strong>" : "يېڭى نەشرى بار: <strong> {newVersionString} </strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "شۇنىڭغا دىققەت قىلىڭكى ، يېڭى ئېلان قىلىنغاندىن كېيىن يېڭىلاش پەقەت تۇنجى قېتىم قويۇپ بېرىلگەندىن كېيىن ياكى كېيىن كۆرۈنىدۇ. ۋاقىتنىڭ ئۆتۈشىگە ئەگىشىپ تارقالغان يېڭى نەشرىنى چىقىرىمىز ، بەزىدە مەسىلە بايقالغاندا بىر نەشرىنى ئاتلاپ ئۆتىمىز. يېڭىلاش ۋە قاناللارنى {link} دىن كۆرۈڭ",
    "Checked on {lastCheckedDate} - Open changelog" : "تەكشۈرۈلگەن {lastCheckedDate} - ئوچۇق ئۆزگەرتىش",
    "Checking apps for compatible versions" : "ماس كېلىدىغان نەشرىدىكى ئەپلەرنى تەكشۈرۈش",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Config.php نىڭ <samp> appstoreenabled </samp> نى يالغان قىلىپ قويمىغانلىقىغا كاپالەتلىك قىلىڭ.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "ئەپ دۇكىنىغا ئۇلىنالمىدى ياكى ھېچقانداق يېڭىلانما قايتۇرۇلمىدى. يېڭىلانمىلارنى قولدا ئىزدەڭ ياكى مۇلازىمېتىرىڭىزنىڭ تورغا چىقالايدىغانلىقىنى ۋە App دۇكىنىغا ئۇلىنالايدىغانلىقىنى جەزملەشتۈرۈڭ.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong> بارلىق </ strong> ئەپلىرىنىڭ بۇ Nextcloud نەشرىگە ماس كېلىدىغان نۇسخىسى بار.",
    "Enterprise" : "كارخانا",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "كارخانا ئىشلىتىش ئۈچۈن. ھەمىشە ئەڭ يېڭى ياماق سەۋىيىسى بىلەن تەمىنلەيدۇ ، ئەمما كېيىنكى ئاساسلىق تارقىتىلىشقا دەرھال يېڭىلانمايدۇ. Nextcloud GmbH چوڭ كۆلەملىك ۋە ۋەزىپىلەرنى ئورۇنداش ئۈچۈن قوشۇمچە قاتتىقلاشتۇرۇش ۋە سىناق ئېلىپ بارغاندىن كېيىن ، بۇ يېڭىلاش يۈز بېرىدۇ. بۇ قانال پەقەت خېرىدارلارغىلا تەمىنلەنگەن بولۇپ ، Nextcloud كارخانا بولىقى بىلەن تەمىنلەيدۇ.",
    "Stable" : "مۇقىم",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "ئەڭ يېڭى مۇقىم نەشرى. ئۇ دائىم ئىشلىتىشكە ماس كېلىدۇ ھەمدە ھەمىشە ئەڭ يېڭى ئاساسلىق نەشرىگە يېڭىلىنىدۇ.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "ئالدىن تارقىتىلغان نۇسخىسى پەقەت يېڭى ئىقتىدارلارنى سىناش ئۈچۈن ، ئىشلەپچىقىرىش مۇھىتى ئۈچۈن ئەمەس.",
    "Changelog for app {app}" : "App {app} for Changelog",
    "What's new in {app} version {version}" : "{app} نەشرى {version} يېڭىلىق نېمە",
    "{version} is available. Get more information on how to update." : "{version} بار. قانداق يېڭىلاش توغرىسىدا تېخىمۇ كۆپ ئۇچۇرلارغا ئېرىشىڭ.",
    "Update to %1$s is available." : "%1 $ s نى يېڭىلاشقا بولىدۇ.",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloud نىڭ يېڭىلاش ئۇقتۇرۇشىنى كۆرسىتىدۇ ۋە يېڭىلاش ئۈچۈن SSO تەمىنلەيدۇ.",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "شۇنىڭغا دىققەت قىلىڭكى ، 100 دىن ئارتۇق ئىشلەتكۈچى بىلەن تور يېڭىلاش تەۋسىيە قىلىنمايدۇ! ئۇنىڭ ئورنىغا بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ!",
    "Please use the command line updater to update." : "يېڭىلاش ئۈچۈن بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ.",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "شۇنىڭغا دىققەت قىلىڭكى ، يېڭى ئېلان قىلىنغاندىن كېيىن يېڭىلاش پەقەت تۇنجى كىچىك ئېلان قىلىنغاندىن كېيىن ياكى كېيىن كۆرۈنىدۇ. بىز ۋاقىتنىڭ ئۆتۈشىگە ئەگىشىپ ئابونتلىرىمىزغا تارقىتىلغان يېڭى نەشرىنى تارقىتىمىز ، بەزىدە مەسىلە بايقالغاندا بىر نەشرىنى ئاتلاپ ئۆتىمىز. يېڭىلاش ۋە قاناللارنى {link} دىن كۆرۈڭ"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/updatenotification/l10n/ug.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "قانال يېڭىلاندى",
    "Web updater is disabled" : "تور يېڭىلاش ئىقتىدارى چەكلەنگەن",
    "Configuration is read-only" : "سەپلىمە بولسا ئوقۇشقىلا-بولىدىغان",
    "App updated" : "ئەپ يېڭىلاندى",
    "See what's new" : "يېڭى نەرسىلەرنى كۆرۈڭ",
    "{app} updated to version {version}" : "{app} نەشرىگە يېڭىلاندى {version}",
    "Update notifications" : "ئۇقتۇرۇشنى يېڭىلاش",
    "The update server could not be reached since %d days to check for new updates." : "يېڭىلاش مۇلازىمىتىرى %d كۈندىن باشلاپ يېڭى يېڭىلانمىلارنى تەكشۈرۈشكە ئېرىشەلمىدى.",
    "Please check the Nextcloud and server log files for errors." : "Nextcloud ۋە مۇلازىمېتىر خاتىرى ھۆججىتىنىڭ خاتالىقلىرىنى تەكشۈرۈپ بېقىڭ.",
    "Update to {serverAndVersion} is available." : "{serverAndVersion} to غا يېڭىلاشقا بولىدۇ.",
    "Update for {app} to version %s is available." : "{app} نى %s نەشرىگە يېڭىلاشقا بولىدۇ.",
    "Update notification" : "ئۇقتۇرۇشنى يېڭىلاش",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Nextcloud نىڭ يېڭىلاش ئۇقتۇرۇشى ، ئەپ يېڭىلانمىلىرىنى كۆرسىتىدۇ ۋە يېڭىلاش ئۈچۈن SSO تەمىنلەيدۇ.",
    "Give feedback" : "پىكىر بېرىڭ",
    "Get started" : "باشلاڭ",
    "No changelog available" : "ئۆزگەرتكىلى بولمايدۇ",
    "What's new in {app} {version}" : "{app} {version} يېڭىلىق نېمە",
    "A new version is available: <strong>{newVersionString}</strong>" : "يېڭى نەشرى بار: <strong> {newVersionString} </strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "شۇنىڭغا دىققەت قىلىڭكى ، يېڭى ئېلان قىلىنغاندىن كېيىن يېڭىلاش پەقەت تۇنجى قېتىم قويۇپ بېرىلگەندىن كېيىن ياكى كېيىن كۆرۈنىدۇ. ۋاقىتنىڭ ئۆتۈشىگە ئەگىشىپ تارقالغان يېڭى نەشرىنى چىقىرىمىز ، بەزىدە مەسىلە بايقالغاندا بىر نەشرىنى ئاتلاپ ئۆتىمىز. يېڭىلاش ۋە قاناللارنى {link} دىن كۆرۈڭ",
    "Checked on {lastCheckedDate} - Open changelog" : "تەكشۈرۈلگەن {lastCheckedDate} - ئوچۇق ئۆزگەرتىش",
    "Checking apps for compatible versions" : "ماس كېلىدىغان نەشرىدىكى ئەپلەرنى تەكشۈرۈش",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Config.php نىڭ <samp> appstoreenabled </samp> نى يالغان قىلىپ قويمىغانلىقىغا كاپالەتلىك قىلىڭ.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "ئەپ دۇكىنىغا ئۇلىنالمىدى ياكى ھېچقانداق يېڭىلانما قايتۇرۇلمىدى. يېڭىلانمىلارنى قولدا ئىزدەڭ ياكى مۇلازىمېتىرىڭىزنىڭ تورغا چىقالايدىغانلىقىنى ۋە App دۇكىنىغا ئۇلىنالايدىغانلىقىنى جەزملەشتۈرۈڭ.",
    "<strong>All</strong> apps have a compatible version for this {productName} version available." : "<strong>بارلىق</strong> ئەپلەرنىڭ بۇ نەشر {productName} گە ماس كېلىدىغان نۇسخىسى بار.",
    "_<strong>%n</strong> app has no compatible version for this {productName} version available._::_<strong>%n</strong> apps have no compatible version for this {productName} version available._" : ["1%n1 ئەپنىڭ بۇ {productName} نۇسخىسىغا ماس كېلىدىغان نۇسخىسى يوق.","1%n1 ئەپنىڭ بۇ {productName} نۇسخىسىغا ماس كېلىدىغان نۇسخىسى يوق."],
    "Enterprise" : "كارخانا",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately." : "كارخانا ئىشلىتىش ئۈچۈن. ھەمىشە ئەڭ يېڭى ياماق دەرىجىسىنى تەمىنلەيدۇ، ئەمما كېيىنكى چوڭ نەشرىگە دەرھال يېڭىلانمايدۇ.",
    "That update happens once {vendor} has done additional hardening and testing for large-scale and mission-critical deployments." : "بۇ يېڭىلاش {vendor} چوڭ كۆلەملىك ۋە مۇھىم ۋەزىپىلەرنى ئورۇنلاشتۇرۇش ئۈچۈن قوشۇمچە قاتتىقلاشتۇرۇش ۋە سىناق قىلغاندىن كېيىن يۈز بېرىدۇ.",
    "This channel is only available to customers and provides the {enterprise} package." : "بۇ قانال پەقەت خېرىدارلار ئۈچۈنلا ئېچىق بولۇپ، {enterprise} بولىقىنى تەمىنلەيدۇ.",
    "Stable" : "مۇقىم",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "ئەڭ يېڭى مۇقىم نەشرى. ئۇ دائىم ئىشلىتىشكە ماس كېلىدۇ ھەمدە ھەمىشە ئەڭ يېڭى ئاساسلىق نەشرىگە يېڭىلىنىدۇ.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "ئالدىن تارقىتىلغان نۇسخىسى پەقەت يېڭى ئىقتىدارلارنى سىناش ئۈچۈن ، ئىشلەپچىقىرىش مۇھىتى ئۈچۈن ئەمەس.",
    "Update" : "يېڭىلا",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "سىز ئىجرا قىلىۋاتقان نەشرى ئەمدى ساقلاپ قېلىنمايدۇ. قوللايدىغان نەشرىگە بالدۇرراق يېڭىلاشقا كاپالەتلىك قىلىڭ.",
    "Apps missing compatible version" : "ماس كېلىدىغان نەشرى يوق",
    "View in store" : "دۇكاندا كۆرۈش",
    "Apps with compatible version" : "ماس نەشرى بار ئەپلەر",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "شۇنىڭغا دىققەت قىلىڭكى ، 100 دىن ئارتۇق ھېسابات بىلەن تور يېڭىلاش تەۋسىيە قىلىنمايدۇ! ئۇنىڭ ئورنىغا بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ!",
    "Open updater" : "يېڭىلاشنى ئېچىڭ",
    "Download now" : "ھازىر چۈشۈرۈڭ",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "تور يېڭىلاش ئىقتىدارى چەكلەنگەن. يېڭىلاش ئۈچۈن بۇيرۇق قۇرىنى يېڭىلاش ياكى قاچىلاش ئۇسۇلىڭىزغا ماس كېلىدىغان يېڭىلاش مېخانىزمىنى (مەسىلەن Docker pull) ئىشلىتىڭ.",
    "What's new?" : "نېمە يېڭىلىق؟",
    "View changelog" : "Changelog نى كۆرۈڭ",
    "The update check is not yet finished. Please refresh the page." : "يېڭىلاش تەكشۈرۈشى تېخى تاماملانمىدى. بەتنى يېڭىلاڭ.",
    "Your version is up to date." : "نەشرىڭىز يېڭىلاندى.",
    "A non-default update server is in use to be checked for updates:" : "يېڭىلانمىلارنى تەكشۈرۈش ئۈچۈن سۈكۈتتىكى يېڭىلاش مۇلازىمىتىرى ئىشلىتىلىۋاتىدۇ:",
    "Update channel" : "قانالنى يېڭىلاش",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "يېڭىلاش قانىلىنى ئۆزگەرتىش ئەپ باشقۇرۇش بېتىگىمۇ تەسىر كۆرسىتىدۇ. مەسىلەن: beta قانىلىغا ئۆتكەندىن كېيىن ، ئەپ باشقۇرۇش بېتىدە beta ئەپ يېڭىلانمىلىرى سىزگە تەمىنلىنىدۇ.",
    "Current update channel:" : "نۆۋەتتىكى يېڭىلاش قانىلى:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "سىز ھەمىشە يېڭى نەشرىگە يېڭىلىيالايسىز. ئەمما سىز تېخىمۇ مۇقىم نەشرىگە ھەرگىز چۈشۈرەلمەيسىز.",
    "Notify members of the following groups about available updates:" : "تۆۋەندىكى گۇرۇپپىلارنىڭ ئەزالىرىغا بار بولغان يېڭىلانمىلارنى ئۇقتۇرۇڭ:",
    "No groups" : "گۇرۇپپا يوق",
    "Only notifications for app updates are available." : "پەقەت ئەپ يېڭىلاش ھەققىدىكى ئۇقتۇرۇشلارلا بار.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "تاللانغان يېڭىلاش قانىلى مۇلازىمېتىرنىڭ ۋاقتى ئۆتكەن.",
    "The selected update channel does not support updates of the server." : "تاللانغان يېڭىلاش قانىلى مۇلازىمېتىرنىڭ يېڭىلىنىشىنى قوللىمايدۇ.",
    "Changelog for app {app}" : "App {app} for Changelog",
    "What's new in {app} version {version}" : "{app} نەشرى {version} يېڭىلىق نېمە",
    "{version} is available. Get more information on how to update." : "{version} بار. قانداق يېڭىلاش توغرىسىدا تېخىمۇ كۆپ ئۇچۇرلارغا ئېرىشىڭ.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong> بارلىق </ strong> ئەپلىرىنىڭ بۇ Nextcloud نەشرىگە ماس كېلىدىغان نۇسخىسى بار.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["1%n1 ئەپلەرنىڭ بۇ Nextcloud نەشىرىگە ماس كېلىدىغان نەشىرلىرى يوق.","<strong>%n</strong> ئەپلەرنىڭ بۇ Nextcloud نەشىرىگە ماس كېلىدىغان نەشىرلىرى يوق."],
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "كارخانا ئىشلىتىش ئۈچۈن. ھەمىشە ئەڭ يېڭى ياماق سەۋىيىسى بىلەن تەمىنلەيدۇ ، ئەمما كېيىنكى ئاساسلىق تارقىتىلىشقا دەرھال يېڭىلانمايدۇ. Nextcloud GmbH چوڭ كۆلەملىك ۋە ۋەزىپىلەرنى ئورۇنداش ئۈچۈن قوشۇمچە قاتتىقلاشتۇرۇش ۋە سىناق ئېلىپ بارغاندىن كېيىن ، بۇ يېڭىلاش يۈز بېرىدۇ. بۇ قانال پەقەت خېرىدارلارغىلا تەمىنلەنگەن بولۇپ ، Nextcloud كارخانا بولىقى بىلەن تەمىنلەيدۇ."
},
"nplurals=2; plural=(n != 1);");
